@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: aeson-pretty
 version: 0.7.2
-id: aeson-pretty-0.7.2-8174b19ca10259cc67493f0b5e4f0938
-key: aeson_8Jlbec9kldS6CZWyTnufnG
+id: aeson-pretty-0.7.2-684969ae92de0502248c3dc24427e52a
+key: aeson_GAGTaMPqfhBBF7VuH7mCJU
 license: BSD3
 copyright: Copyright 2011 Falko Peters
 maintainer: Falko Peters <falko.peters@gmail.com>
@@ -34,9 +34,9 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/aeson-pretty-0.7.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/aeson-pretty-0.7.2
-hs-libraries: HSaeson-pretty-0.7.2-8Jlbec9kldS6CZWyTnufnG
+hs-libraries: HSaeson-pretty-0.7.2-GAGTaMPqfhBBF7VuH7mCJU
 depends:
-    aeson-0.11.1.4-4ad27f2347131dcc86b1af72cd00fe7c
+    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
